==> activity-center-api-0.10.16sjq-20191127.045021-2-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/AdvertisingSpaceStyleMaterialUpdateDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/11/20
 */
public class AdvertisingSpaceStyleMaterialUpdateDto implements Serializable {

    private Long id;

    /** 广告位样式ID **/
    private Long adStyleId;

    /** 广告位样式类型：1.图片 2.视频 **/
    private Integer type;

    /** 素材宽度 **/
    private Integer width;

    /** 素材高度 **/
    private Integer height;

    /** 素材大小 **/
    private Integer size;

    /** 素材单位 **/
    private String unit;

    /** 素材格式 **/
    private String format;

    /** 视频时长 **/
    private Integer duration;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdStyleId() {
        return adStyleId;
    }

    public void setAdStyleId(Long adStyleId) {
        this.adStyleId = adStyleId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getWidth() {
        return width;
    }

    public void setWidth(Integer width) {
        this.width = width;
    }

    public Integer getHeight() {
        return height;
    }

    public void setHeight(Integer height) {
        this.height = height;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getFormat() {
        return format;
    }

    public void setFormat(String format) {
        this.format = format;
    }

    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> activity-center-api-0.10.46sjq-20191212.082214-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/AdvertisingSpaceStyleMaterialUpdateDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.List;

/**
 * @author shenjiaqing
 * @description
 * @data 2019/11/20
 */
public class AdvertisingSpaceStyleMaterialUpdateDto implements Serializable {

    private Long id;

    /** 广告位样式ID **/
    private Long adStyleId;

    /** 广告位样式类型：1.图片 2.视频 **/
    private Integer type;

    /** 素材宽度 **/
    private Integer width;

    /** 素材高度 **/
    private Integer height;

    /** 素材大小 **/
    private Integer size;

    /** 素材单位 **/
    private String unit;

    /** 素材格式 **/
    private List<String> formats;

    /** 视频时长 **/
    private Integer duration;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdStyleId() {
        return adStyleId;
    }

    public void setAdStyleId(Long adStyleId) {
        this.adStyleId = adStyleId;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getWidth() {
        return width;
    }

    public void setWidth(Integer width) {
        this.width = width;
    }

    public Integer getHeight() {
        return height;
    }

    public void setHeight(Integer height) {
        this.height = height;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public List<String> getFormats() {
        return formats;
    }

    public void setFormats(List<String> formats) {
        this.formats = formats;
    }

    public Integer getDuration() {
        return duration;
    }

    public void setDuration(Integer duration) {
        this.duration = duration;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
